# Manual playlists

This feature lets you temporarily deactivate automatic playlists. You can specify a label filter and duration. Example:

    $ ardj play --time=600 lounge +instrumental

From this moment and for the next 600 minutes only instrumental lounge music will be playing. No jingles or other interrupts. After that, automatic playlists will start working again.

To play a set of individual tracks, there's the queue.